.. _cli-create:

======
create
======

Use this command to create a graph from a recipe file.

The syntax of the recipe file is described in :doc:`building graphs <../graphs/introduction>`.

.. argparse::
    :module: anemoi.graphs.__main__
    :func: create_parser
    :prog: anemoi-graphs
    :path: create
